//------------------------------------------------------
//                                                        
//  File          :  top.sv
//  Related Files :                                                     
//  Author(s)     :  Mueller                              
//  Email         :  muelleral82290@th-nuernberg.de       
//  Organization  :  Georg-Simon-Ohm-Hochschule Nuernberg 
//  Notes         :  Stimuli Modul 
//
//------------------------------------------------------
//                   History    
//------------------------------------------------------
//    Version| Author   | Mod. Date  | Changes Made:
//    v1.00  | Mueller  | 27/04/2023 | first code
//------------------------------------------------------
//eoh

//interface for LED
//reg [2:0]rbg stores rgb values that depend on dip[3:2]

//interface for DIPSCHALER
// dip[3:2] -> select colour, dip[1] -> read ~ 1/write ~ 0, dip[0] -> on ~ 1/off ~ 0

//interface for FRAM
// sck -> 0 ~ cummonication enabled, 1 ~ communication disabled
// clk -> system clock / timer
// miso -> testbench output
// mosi -> testbench input

//testbenchclock replaces the oscillator on the board

`timescale 10us/10ns

module top_tb();

	//  Interface
	led_if   stim_led_if();
	dip_if	 stim_dip_if();
	fram_if  stim_fram_if();	
	clock_if stim_clock_if();			
		
	// Instanziierungen
	top     t1(stim_led_if, stim_dip_if, stim_fram_if, stim_clock_if);
	stimuli s1(stim_led_if, stim_dip_if, stim_clock_if);
	//fram_module f1(stim_fram_if);

	// assertions
	//`include "./hdl_src/sv/led_assert.txt"

endmodule : top_tb


